|build_status|


Micromouse Maze Simulator
=========================

The simulator acts as a server and can load different mazes. Any client can
connect to it to ask for the current position walls, move from one cell to
another and visualize the simulated micromouse state.


.. |build_status|
   image:: https://api.travis-ci.org/Theseus/maze-simulator.svg?branch=master
      :target: https://travis-ci.org/Theseus/maze-simulator
